@@ -449,9 +449,10 @@ OC.L10N.register(
     "Train from {depStation} to {arrStation}" : "Tren desde {depStation} a {arrStation}",
     "Train" : "Tren",
     "Flag" : "Bandera",
+    "Recipient" : "Destinatario",
     "Operator" : "Operador",
-    "Actions" : "Acciones",
-    "New action" : "Nueva acción",
+    "contains" : "contiene",
+    "matches" : "coincide",
     "Priority" : "Prioridad",
     "Successfully updated config for \"{domain}\"" : "Configuración actualizada con éxito para \"{domain}\"",
     "Error saving config" : "Error al guardar la configuración",
@@ -588,7 +589,7 @@ OC.L10N.register(
     "The link leads to %s" : "La liga lleva a %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Si no deseas visitar esa página, puedes regresar a <a href=\"%s\">Correo</a>.",
     "Continue to %s" : "Continuar a %s",
-    "Microsoft allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection." : "Microsoft permite a los usuarios acceder a su correo electrónico a través de IMAP. Por razones de seguridad, este acceso solo es posible con una conexión OAuth 2.0.",
-    "You have to register a new app in the Microsoft Azure Active Directory portal. Add the URL {url} as redirect URI." : "Debes registrar una nueva aplicación en el portal de Microsoft Azure Active Directory. Agrega la URL {url} como URI de redirección."
+    "Actions" : "Acciones",
+    "New action" : "Nueva acción"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
