@@ -64,7 +64,7 @@ OC.L10N.register(
     "Mail address" : "E-posti aadress",
     "name@example.org" : "nimi@toredomeen.ee",
     "Please enter an email of the format name@example.com" : "Palun sisesta e-posti aadress nimi@toredomeen.ee vormingus",
-    "Password" : "Parool",
+    "Password" : "Salasõna",
     "Manual" : "Käsitsi",
     "IMAP Settings" : "IMAP-i seadistused",
     "IMAP Host" : "IMAP-i server",
@@ -74,7 +74,7 @@ OC.L10N.register(
     "STARTTLS" : "STARTTLS",
     "IMAP Port" : "IMAP-i port",
     "IMAP User" : "IMAP-i kasutajanimi",
-    "IMAP Password" : "IMAP-i salasüna",
+    "IMAP Password" : "IMAP-i salasõna",
     "SMTP Settings" : "SMTP seadistused",
     "SMTP Host" : "SMTP server",
     "SMTP Security" : "SMTP turvalisus",
