@@ -582,6 +582,7 @@ OC.L10N.register(
     "Delete action" : "Ezabatu ekintza",
     "Flag" : "Bandera",
     "The stop action ends all processing" : "Gelditze-ekintzak prozesua amaitzen du.",
+    "Recipient" : "Hartzailea",
     "Delete filter" : "Ezabatu iragazkia",
     "Delete mail filter {filterName}?" : "Ezabatu {filterName} posta-iragazkia?",
     "Are you sure to delete the mail filter?" : "Ziur zaude posta-iragazkia ezabatu nahi duzula?",
@@ -594,23 +595,19 @@ OC.L10N.register(
     "Filter is active" : "Iragazkia gaituta dago",
     "Filter is not active" : "Iragazkia desgaituta dago",
     "Operator" : "Eragilea",
-    "If all tests pass, then the actions will be executed" : "Proba guztiak gaindituz gero, ekintzak burutu egingo dira",
-    "If one test pass, then the actions will be executed" : "Proba bat gaindituz gero, ekintzak burutu egingo dira",
+    "contains" : "dauka",
+    "matches" : "bat dator",
     "Delete test" : "Ezabatu proba",
     "Update mail filter" : "Eguneratu posta iragazkia",
     "Filter name" : "Iragaziaren izena",
-    "Tests" : "Probak",
     "Tests are applied to incoming emails on your mail server, targeting fields such as subject (the email's subject line), from (the sender), and to (the recipient). You can use the following operators to define conditions for these fields:" : "Zure posta-zerbitzarian sartzen diren posta elektronikoei aplikatzen zaizkie probak. Eremu hauek probatzen dira: gaia (posta elektronikoaren gai-lerroa), bidaltzailea eta hartzailea. Honako eragile hauek erabil ditzakezu eremu horietarako baldintzak zehazteko:",
     "An exact match. The field must be identical to the provided value." : "Bat etortze zehatza. Eremuak emandako balioaren berdina izan behar du.",
     "A substring match. The field matches if the provided value is contained within it. For example, \"report\" would match \"port\"." : "Azpikate bat etortzea. Eremua bat dator emandako balioa barruan badago. Adibidez, \"aireportua\" bat etorriko litzake \"portua\"-rekin.",
     "A pattern match using wildcards. The \"*\" symbol represents any number of characters (including none), while \"?\" represents exactly one character. For example, \"*report*\" would match \"Business report 2024\"." : "Patroi bat etortzea komodinak erabiliz. «*» sinboloa edozein karaktere (ezer ez barne) kopuru adierazten du. Bestalde, «?» karaktere bakarra adierazten du. Adibidez «*txosten*» «2024ko txostena»-rekin bat etorriko litzateke.",
-    "New test" : "Proba berria",
-    "Actions" : "Ekintzak",
     "Actions are triggered when the specified tests are true. The following actions are available:" : "Ekintzak zehaztutako probak egiazkoak direnean abiarazten dira. Honako ekintza hauek daude:",
     "Moves the message into a specified folder." : "Mezua karpeta zehatz batera eramaten du.",
     "Adds a flag to the message." : "Bandera bat gehitzen dio mezuari.",
     "Halts the execution of the filter script. No further filters with will be processed after this action." : "Iragazpen scriptaren exekuzioa geldiarazten du. Ekintza honen ondoren ez da iragazki gehiagorik prozesatuko.",
-    "New action" : "Ekintza berria",
     "Priority" : "Lehentasuna",
     "Enable filter" : "Gaitu iragazkia",
     "Save filter" : "Gorde iragazkia",
@@ -761,7 +758,11 @@ OC.L10N.register(
     "The link leads to %s" : "Estekak hona bideratzen du: %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Orrialde hori bisitatu nahi ez baduzu, itzul dezakezu <a href=\"%s\">Mail </a>-ra.",
     "Continue to %s" : "Jarraitu hona: %s",
-    "Microsoft allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection." : "Microsoft-ek erabiltzaileei euren posta elektronikora sartzeko baimena ematen die IMAP bidez. Segurtasun arrazoiengatik, sarbide hori OAuth 2.0 konexio batekin bakarrik da posible.",
-    "You have to register a new app in the Microsoft Azure Active Directory portal. Add the URL {url} as redirect URI." : "Aplikazio berri bat erregistratu behar duzu Microsoft Azure Active Directory atarian. Gehitu {url} URLa birbideratzeko URI gisa."
+    "If all tests pass, then the actions will be executed" : "Proba guztiak gaindituz gero, ekintzak burutu egingo dira",
+    "If one test pass, then the actions will be executed" : "Proba bat gaindituz gero, ekintzak burutu egingo dira",
+    "Tests" : "Probak",
+    "New test" : "Proba berria",
+    "Actions" : "Ekintzak",
+    "New action" : "Ekintza berria"
 },
 "nplurals=2; plural=(n != 1);");
