@@ -482,8 +482,8 @@ OC.L10N.register(
     "Flag" : "Flag",
     "Delete filter" : "Delete filter",
     "Operator" : "Operator",
-    "Actions" : "کنش‌ها",
-    "New action" : "New action",
+    "contains" : "contains",
+    "matches" : "مطابق است",
     "Priority" : "اولویت",
     "Successfully updated config for \"{domain}\"" : "Successfully updated config for \"{domain}\"",
     "Error saving config" : "Error saving config",
@@ -611,7 +611,7 @@ OC.L10N.register(
     "The link leads to %s" : "پیوند منجر به%s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>.",
     "Continue to %s" : "ادامه دهید%s",
-    "Microsoft allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection." : "Microsoft allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection.",
-    "You have to register a new app in the Microsoft Azure Active Directory portal. Add the URL {url} as redirect URI." : "You have to register a new app in the Microsoft Azure Active Directory portal. Add the URL {url} as redirect URI."
+    "Actions" : "کنش‌ها",
+    "New action" : "New action"
 },
 "nplurals=2; plural=(n > 1);");
