@@ -407,11 +407,12 @@ OC.L10N.register(
     "Train from {depStation} to {arrStation}" : "Juna asemalta {depStation} asemalle {arrStation}",
     "Train" : "Juna",
     "Flag" : "Lippu",
+    "Recipient" : "Vastaanottaja",
     "Delete filter" : "Poista suodatin",
     "Operator" : "Operaattori",
+    "contains" : "sisältää",
+    "matches" : "täsmää",
     "Filter name" : "Nimisuodatin",
-    "Actions" : "Toiminnot",
-    "New action" : "Uusi toiminto",
     "Priority" : "Tärkeys",
     "Mail app" : "Sähköpostisovellus",
     "The mail app allows users to read mails on their IMAP accounts." : "Tämä sähköpostisovellus mahdollistaa käyttäjien lukea sähköpostiviestejä IMAP-tileiltä.",
@@ -495,7 +496,7 @@ OC.L10N.register(
     "Redirect" : "Uudelleenohjaus",
     "The link leads to %s" : "Tämä linkki johtaa kohteeseen %s",
     "Continue to %s" : "Jatka sivulle %s",
-    "Microsoft allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection." : "Microsoft sallii käyttäjien yhdistää sähköpostiin IMAP:ia käyttäen. Tietoturvasyistä tällainen käyttö on mahdollista vain OAuth 2.0 -yhteydellä.",
-    "You have to register a new app in the Microsoft Azure Active Directory portal. Add the URL {url} as redirect URI." : "Rekisteröi uusi sovellus Microsoft Azure Active Directory -portaalissa. Lisää URL-osoite {url} uudelleenohjauksen URI:ksi."
+    "Actions" : "Toiminnot",
+    "New action" : "Uusi toiminto"
 },
 "nplurals=2; plural=(n != 1);");
