@@ -589,6 +589,7 @@ OC.L10N.register(
     "Delete action" : "アクションを削除",
     "Flag" : "フラグ",
     "The stop action ends all processing" : "stop アクションは、すべての処理を終了します",
+    "Recipient" : "受信者",
     "Delete filter" : "フィルターを削除",
     "Delete mail filter {filterName}?" : "メールフィルター{filterName}を削除しますか？",
     "Are you sure to delete the mail filter?" : "メールフィルターを削除してよろしいですか？",
@@ -601,23 +602,19 @@ OC.L10N.register(
     "Filter is active" : "フィルターが有効",
     "Filter is not active" : "フィルターが無効",
     "Operator" : "条件",
-    "If all tests pass, then the actions will be executed" : "すべてのテストがパスすれば、アクションが実行されます",
-    "If one test pass, then the actions will be executed" : "テストが1つでもパスすれば、アクションが実行されます",
+    "contains" : "を含む",
+    "matches" : "一致",
     "Delete test" : "テストを削除",
     "Update mail filter" : "メールフィルターを更新する",
     "Filter name" : "フィルター名",
-    "Tests" : "テスト",
     "Tests are applied to incoming emails on your mail server, targeting fields such as subject (the email's subject line), from (the sender), and to (the recipient). You can use the following operators to define conditions for these fields:" : "テストは、Subject（メールの件名）、From（送信者）、To（受信者）などのフィールドを対象として、メールサーバー上の受信メールに適用されます。以下の演算子を使用して、これらのフィールドの条件を定義できます：",
     "An exact match. The field must be identical to the provided value." : "完全一致。フィールドは提供された値と同一でなければなりません。",
     "A substring match. The field matches if the provided value is contained within it. For example, \"report\" would match \"port\"." : "部分文字列のマッチ。提供された値がそのフィールドに含まれる場合にマッチする。例えば、「report 」は 「port 」にマッチする。",
     "A pattern match using wildcards. The \"*\" symbol represents any number of characters (including none), while \"?\" represents exactly one character. For example, \"*report*\" would match \"Business report 2024\"." : "ワイルドカードを使ったパターン・マッチ。記号 「*」は任意の文字数（ない場合も含む）を表し、「? 」は正確に1文字を表す。例えば、「*report*」は 「Business report 2024 」にマッチする。",
-    "New test" : "新しいテスト",
-    "Actions" : "アクション",
     "Actions are triggered when the specified tests are true. The following actions are available:" : "アクションは、指定されたテストが真であるときにトリガーされる。以下のアクションが利用可能です：",
     "Moves the message into a specified folder." : "メッセージを指定したフォルダーに移動します。",
     "Adds a flag to the message." : "メッセージにフラグを追加する。",
     "Halts the execution of the filter script. No further filters with will be processed after this action." : "フィルタースクリプトの実行を停止する。この操作の後、それ以降のフィルターは処理されません。",
-    "New action" : "新しいアクション",
     "Priority" : "優先度",
     "Enable filter" : "フィルターを有効にする",
     "Save filter" : "フィルターを保存する",
@@ -768,7 +765,11 @@ OC.L10N.register(
     "The link leads to %s" : "リンクが %s につながります",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "ページにアクセスしたくない場合は、<a href=\"%s\">メール</a>に戻ることができます",
     "Continue to %s" : "%s にリダイレクトする",
-    "Microsoft allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection." : "Microsoftは、ユーザーがIMAP経由で電子メールにアクセスすることを許可しています。セキュリティ上の理由から、このアクセスはOAuth 2.0接続でのみ可能です。",
-    "You have to register a new app in the Microsoft Azure Active Directory portal. Add the URL {url} as redirect URI." : "Microsoft Azure Active Directoryポータルで新しいアプリを登録する必要があります。リダイレクトURIとしてURL{url}を追加します。"
+    "If all tests pass, then the actions will be executed" : "すべてのテストがパスすれば、アクションが実行されます",
+    "If one test pass, then the actions will be executed" : "テストが1つでもパスすれば、アクションが実行されます",
+    "Tests" : "テスト",
+    "New test" : "新しいテスト",
+    "Actions" : "アクション",
+    "New action" : "新しいアクション"
 },
 "nplurals=1; plural=0;");
