@@ -3,14 +3,15 @@ OC.L10N.register(
     {
     "Personal" : "Udmawan",
     "Mail" : "Tirawt",
+    "Save" : "Sekles",
     "Name" : "Nom",
     "Password" : "Awal uffir",
     "None" : "Ula d yiwen",
-    "Save" : "Sekles",
     "Email address" : "Tansa imayl",
     "Cancel" : "Sefsex",
     "Accounts" : "Imiḍanen",
     "General" : "Amatu",
+    "About" : "Γef",
     "Delete" : "Kkes",
     "Search" : "Nadi",
     "Send" : "Tuzna",
@@ -25,12 +26,13 @@ OC.L10N.register(
     "Remove" : "Kkes",
     "Other" : "Wayeḍ",
     "Forward" : "Avancer",
+    "Translate" : "Suqel",
     "Move" : "Senkez",
-    "Remove account" : "Kkes amiḍan",
     "Loading …" : "Asali ...",
+    "Remove account" : "Kkes amiḍan",
     "Rename" : "Beddel isem",
-    "Retry" : "Ɛreḍ tikkelt-nniḍen",
     "Reply" : "Err",
+    "Retry" : "Ɛreḍ tikkelt-nniḍen",
     "Message" : "Izen",
     "Copy to clipboard" : "Copier dans le presse-papiers",
     "Add" : "Rnu",
