@@ -1,38 +1,54 @@
 OC.L10N.register(
     "mail",
     {
+    "Important" : "Muhimu",
     "Personal" : "Binafsi",
     "To Do" : "Kufanya",
     "Later" : "Baadaye",
+    "Sign in with Google" : "Ingia kwa Google",
     "Save" : "Hifadhi",
     "Name" : "Jina",
+    "Password" : "Nenosiri",
+    "None" : "Hakuna",
+    "Signature" : "Saini",
     "Go back" : "Rudi nyuma",
     "Email address" : "Anwani ya barua pepe",
     "Cancel" : "Cancel",
+    "Accounts" : "Akaunti",
+    "General" : "Kuu",
+    "Layout" : "Mpangilio",
     "List" : "Orodha",
+    "About" : "Kuhusu",
     "Keyboard shortcuts" : "Mikato ya keyboard",
     "Delete" : "Futa",
     "Search" : "Tafuta",
     "From" : "Tangu/ kutoka",
     "To" : "Mpaka/ hadi",
+    "Choose" : "Chagua",
     "Choose a file to add as attachment" : "Chagua faili kuongeza kama kiambatanisho",
     "Choose a file to share as a link" : "Chagua faili kushirikisha kama kiungo",
+    "_{count} attachment_::_{count} attachments_" : ["{count} attachment","{count} attachments"],
     "Confirm" : "Thibitisha",
     "Later today – {timeLocale}" : "Baadaye leo-{timeLocale}",
     "Tomorrow – {timeLocale}" : "Kesho-{timeLocale}",
     "This weekend – {timeLocale}" : "Wikendi-{timeLocale}",
     "Next week – {timeLocale}" : "Wiki ijayo-{timeLocale}",
     "Favorite" : "Kipendwa",
+    "More actions" : "Vitendo zaidi",
     "Back" : "Rudi",
     "Create event" : "Tengeneza matukio",
+    "Create task" : "Tengeneza jukumu",
     "Load more" : "Pakia zaidi",
     "All day" : "Siku yote",
     "Description" : "Maelezo",
     "Create" : "Tengeneza",
+    "Comment" : "Maoni",
     "Accept" : "Kubali",
     "Decline" : "Kataa",
     "Other" : "Mengine",
+    "Translate" : "Tafsiri",
     "Move" : "Hamisha",
+    "Loading …" : "Inapakia",
     "{usage} of {limit} used" : "{usage} ya {limit}imetumika",
     "Rename" : "Ipe jina jipya",
     "Subscribed" : "Iliyojisajili",
@@ -44,11 +60,22 @@ OC.L10N.register(
     "Close" : "Funga",
     "Date" : "Tarehe",
     "Tags" : "Maoni",
+    "Select tags" : "Chagua ukumbusho",
     "Last 7 days" : "Siku 7 zilizopita",
+    "Not found" : "Haipatikani",
     "Untitled event" : "Tukio lisilotajwa",
     "(organizer)" : "(Mratibu)",
+    "Priority" : "Kipaumbele",
+    "Reset" : "Pangilia upya",
+    "Client ID" : "Kitambulisho cha mteja",
+    "Client secret" : "Siri ya mteja",
+    "Valid until" : "Halali mpaka",
     "Submit" : "Wasilisha",
+    "Account connected" : "Akaunti imeunganishwa",
+    "All" : "Zote",
     "Favorites" : "Vipendwa",
+    "Error while sharing file" : "Hitilafu wakati wa kushirikisha faili",
+    "Continue to %s" : "Endelea katika %s",
     "Actions" : "Utendekaji"
 },
 "nplurals=2; plural=(n != 1);");
