@@ -506,8 +506,8 @@ OC.L10N.register(
     "Train" : "Потяг",
     "Delete filter" : "Вилучити фільтр",
     "Operator" : "Оператор",
-    "Actions" : "Дії",
-    "New action" : "Нова дія",
+    "contains" : "містить",
+    "matches" : "містить",
     "Priority" : "Пріоритет",
     "Mail app" : "Електронна пошта",
     "The mail app allows users to read mails on their IMAP accounts." : "Застосунок пошти дозволяє користувачам переглядати з їхніх облікових записів IMAP.",
@@ -568,6 +568,8 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Натисніть тут, якщо вас не буде автоматично перенаправлено протягом наступних кількох секунд.",
     "Redirect" : "Перенаправлення",
     "The link leads to %s" : "Посилання веде до %s",
-    "Continue to %s" : "Перейти до %s"
+    "Continue to %s" : "Перейти до %s",
+    "Actions" : "Дії",
+    "New action" : "Нова дія"
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
